@@ -365,7 +365,9 @@ impl Options {
                 }),
                 syntax.decorators()
             ),
-            import_assertions(),
+            // The transform strips import assertions, so it's only enabled if
+            // keep_import_assertions is false.
+            Optional::new(import_assertions(), !experimental.keep_import_assertions),
             // Do a resolver pass after decorators as it might
             // emit runtime declarations and do it before
             // type stripping as we need to know scope information
@@ -932,6 +934,9 @@ pub struct JscExperimental {
     /// This requires cargo feature `plugin`.
     #[serde(default)]
     pub plugins: Option<Vec<PluginConfig>>,
+    /// If true, keeps import assertions in the output.
+    #[serde(default)]
+    pub keep_import_assertions: bool,
 }
 
 impl Merge for JscExperimental {
